pub struct LigCaretList<'a> {
data: FontData<'a>,
}Expand description
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> LigCaretList<'a>
impl<'a> LigCaretList<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn coverage_offset(&self) -> Offset16
pub fn coverage_offset(&self) -> Offset16
Offset to Coverage table - from beginning of LigCaretList table
Sourcepub fn coverage(&self) -> Result<CoverageTable<'a>, ReadError>
pub fn coverage(&self) -> Result<CoverageTable<'a>, ReadError>
Attempt to resolve coverage_offset.
Sourcepub fn lig_glyph_count(&self) -> u16
pub fn lig_glyph_count(&self) -> u16
Number of ligature glyphs
Sourcepub fn lig_glyph_offsets(&self) -> &'a [BigEndian<Offset16>]
pub fn lig_glyph_offsets(&self) -> &'a [BigEndian<Offset16>]
Array of offsets to LigGlyph tables, from beginning of LigCaretList table —in Coverage Index order
Sourcepub fn lig_glyphs(&self) -> ArrayOfOffsets<'a, LigGlyph<'a>, Offset16>
pub fn lig_glyphs(&self) -> ArrayOfOffsets<'a, LigGlyph<'a>, Offset16>
A dynamically resolving wrapper for lig_glyph_offsets.
pub fn coverage_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn lig_glyph_count_byte_range(&self) -> Range<usize> ⓘ
pub fn lig_glyph_offsets_byte_range(&self) -> Range<usize> ⓘ